@@ -84,8 +84,6 @@ const struct modes cmodes[] = {
 	{ "-clocal",	0, CLOCAL },
 	{ "crtscts",	CRTSCTS, 0 },
 	{ "-crtscts",	0, CRTSCTS },
-	{ "mdmbuf",	MDMBUF, 0 },
-	{ "-mdmbuf",	0, MDMBUF },
 	{ NULL },
 };
 
@@ -108,8 +106,10 @@ const struct modes imodes[] = {
 	{ "-igncr",	0, IGNCR },
 	{ "icrnl",	ICRNL, 0 },
 	{ "-icrnl",	0, ICRNL },
+#ifdef IUCLC	
 	{ "iuclc",	IUCLC, 0 },
 	{ "-iuclc",	0, IUCLC },
+#endif	
 	{ "ixon",	IXON, 0 },
 	{ "-ixon",	0, IXON },
 	{ "flow",	IXON, 0 },
@@ -142,8 +142,6 @@ const struct modes lmodes[] = {
 	{ "-echoke",	0, ECHOKE },
 	{ "crtkill",	ECHOKE, 0 },
 	{ "-crtkill",	0, ECHOKE },
-	{ "altwerase",	ALTWERASE, 0 },
-	{ "-altwerase",	0, ALTWERASE },
 	{ "iexten",	IEXTEN, 0 },
 	{ "-iexten",	0, IEXTEN },
 	{ "echonl",	ECHONL, 0 },
@@ -172,12 +170,10 @@ const struct modes lmodes[] = {
 	{ "-crt",	ECHOK, ECHOE|ECHOKE|ECHOCTL },
 	{ "newcrt",	ECHOE|ECHOKE|ECHOCTL, ECHOK|ECHOPRT },
 	{ "-newcrt",	ECHOK, ECHOE|ECHOKE|ECHOCTL },
-	{ "nokerninfo",	NOKERNINFO, 0 },
-	{ "-nokerninfo",0, NOKERNINFO },
-	{ "kerninfo",	0, NOKERNINFO },
-	{ "-kerninfo",	NOKERNINFO, 0 },
+#ifdef XCASE	
 	{ "xcase",	XCASE, 0 },
 	{ "-xcase",	0, XCASE },
+#endif	
 	{ NULL },
 };
 
@@ -188,18 +184,20 @@ const struct modes omodes[] = {
 	{ "-litout",	OPOST, 0 },
 	{ "ocrnl",	OCRNL, 0 },
 	{ "-ocrnl",	0, OCRNL },
+#ifdef OLCUC	
 	{ "olcuc",	OLCUC, 0 },
 	{ "-olcuc",	0, OLCUC },
+#endif	
 	{ "onlcr",	ONLCR, 0 },
 	{ "-onlcr",	0, ONLCR },
 	{ "onlret",	ONLRET, 0 },
 	{ "-onlret",	0, ONLRET },
 	{ "onocr",	ONOCR, 0 },
 	{ "-onocr",	0, ONOCR },
-	{ "tabs",	0, OXTABS },		/* "preserve" tabs */
-	{ "-tabs",	OXTABS, 0 },
-	{ "oxtabs",	OXTABS, 0 },
-	{ "-oxtabs",	0, OXTABS },
+	{ "tabs",	0, XTABS },		/* "preserve" tabs */
+	{ "-tabs",	XTABS, 0 },
+	{ "oxtabs",	XTABS, 0 },
+	{ "-oxtabs",	0, XTABS },
 	{ NULL },
 };
 
